
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>
#include <clapper-gtk/clapper-gtk-visibility.h>

G_BEGIN_DECLS

/* enumerations from "clapper-gtk-enums.h" */

CLAPPER_GTK_API
GType clapper_gtk_video_action_mask_get_type (void);
#define CLAPPER_GTK_TYPE_VIDEO_ACTION_MASK (clapper_gtk_video_action_mask_get_type())

G_END_DECLS

/* Generated data ends here */

